(
	/*
	QuickRender toolbar

	Render the current frame of the currently focused viewport without saving anything. 
	A sequence is NOT rendered, just the current time frame. No render elements get saved, no images get saved and no questions are asked of the user. Nothing ever gets saved.
	I would love a set of these test render buttons that would render 100%, 50% and 25% of the current resolution. 
	Also a button that renders this test frame progressive or bucket without being sticky.
	*/
	
	global quickRendRoll 
	try (destroyDialog quickRendRoll) catch()
	
	local oldSamplerMode = 3
	local oldMax = false
	local oldRaw = false
	local oldSplit = false
	local oldResume = false
	local oldReState = true
	local oldRendRes = #(1,1)
	
	
	-- Sampler Mode
	fn getRendMode =
	(
		oldSamplerMode = renderers.current.imageSampler_type
	)
	
	fn setRendMode mode =	
	(
		case mode of  
		(
			"prog" : 
			(
				renderers.current.imageSampler_type = 3
			)
			"buck" :
			(
				renderers.current.imageSampler_type = 1
			)
		)	
	)
	
	fn resetRendMode =
	(
		renderers.current.imageSampler_type = oldSamplerMode
	)
	
	-- Outputs
	fn getOutputs =
	(
		oldMax = rendSaveFile 
		oldRaw = renderers.current.output_saveRawFile
		oldSplit = renderers.current.output_splitgbuffer
		oldResume = renderers.current.output_resumableRendering
	)
	
	fn setOutputs = 
	(
		rendSaveFile = off
		renderers.current.output_saveRawFile = off
		renderers.current.output_splitgbuffer = off
		renderers.current.output_resumableRendering = off
	)
	
	fn resetOutputs = 
	(
		rendSaveFile = oldMax
		renderers.current.output_saveRawFile = oldRaw
		renderers.current.output_splitgbuffer = oldSplit
		renderers.current.output_resumableRendering = oldResume
	)
	
	-- Render Elements
	fn getReState =
	(
		rem = maxOps.GetCurRenderElementMgr()
		oldReState = rem.GetElementsActive() 
	)
	
	fn SetReState =
	(
		rem = maxOps.GetCurRenderElementMgr()
		rem.setElementsActive false
	)
	
	fn resetReState =
	(
		rem = maxOps.GetCurRenderElementMgr()
		rem.setElementsActive oldReState		
	)
	
	--Resolution
	fn getRes =
	(
		if renderers.current.output_getsetsfrommax then
		(
			oldRendRes = #(renderWidth, renderHeight)
		)
		else
		(
			oldRendRes = #(renderers.current.output_width, renderers.current.output_height)
		)
	)
	
	fn setRes res = 
	(
		res /= 100.0 --normalise 
		if renderers.current.output_getsetsfrommax then
		(
			renderwidth = oldRendRes[1] * res
			renderHeight = oldRendRes[2] * res
		)
		else
		(
			renderers.current.output_width = oldRendRes[1] * res
			renderers.current.output_height = oldRendRes[2] * res
		)
	)
	
	fn resetRes = 
	(
		if renderers.current.output_getsetsfrommax then
		(
			renderwidth = oldRendRes[1]
			renderHeight = oldRendRes[2]
		)
		else
		(
			renderers.current.output_width = oldRendRes[1] 
			renderers.current.output_height = oldRendRes[2]
		)		
	)
	
	fn renderThis res mode= --res is an integer, mode is either "prog" or "buck"
	(
		getRendMode()
		getOutputs()
		getReState()
		getRes()
		
		setRendMode mode
		setOutputs()
		setReState()
		setRes res
		
		render vfb:off

		resetRendMode()
		resetOutputs()
		resetReState()
		resetRes()
	)
	
	
	rollout quickRendRoll "Quick Render Shortcuts" width:328 height:80
	(
		groupBox 'grp1' "Bucket" pos:[8,8] width:152 height:64 align:#left
		button 'btn1' "100%" pos:[16,24] width:40 height:40 align:#left
		button 'btn2' "50%" pos:[64,24] width:40 height:40 align:#left
		button 'btn3' "25%" pos:[112,24] width:40 height:40 align:#left
		groupBox 'grp2' "Progressive" pos:[168,8] width:152 height:64 align:#left
		button 'btn4' "100%" pos:[176,24] width:40 height:40 align:#left
		button 'btn5' "50%" pos:[224,24] width:40 height:40 align:#left
		button 'btn6' "25%" pos:[272,24] width:40 height:40 align:#left
		
		on btn1 pressed do 
		(
			renderThis 100 "buck"
		)
		on btn2 pressed do 
		(
			renderThis 50 "buck"
		)		
		on btn3 pressed do 
		(
			renderThis 25 "buck"
		)		
		on btn4 pressed do 
		(
			renderThis 100 "prog"
		)			
		on btn5 pressed do 
		(
			renderThis 50 "prog"
		)	
		on btn6 pressed do 
		(
			renderThis 25 "prog"
		)		
	)

	createDialog quickRendRoll
)